C**********************************************************************
C                           ADAPT                                     *
C                         Version 5                                   *
C**********************************************************************
C                                                                     *
C Version 1 : 12.09.11                                                *
C                                                                     *
C Experiment B                                                        *
C                                                                     *
C           PKPD MODEL - Arthritis Model in ODE formulation           *
C                                                                     *
C   Gilbert Koch (gilbert.koch@uni-konstanz.de)                       *
C                                                                     *
C   A multi-response model for rheumatoid arthritis based on          *
C   delay differential equations in collagen-induced arthritic mice   *
C   treated with an anti-GM-CSF antibody                              *
C                                                                     *
C                                                                     *
C                                                                     *
C    This file contains Fortran subroutines into which the user       *
C    must enter the relevant model equations and constants.           *
C    Consult the User's Guide for details concerning the format for   *
C    entered equations and definition of symbols.                     *
C                                                                     *
C       1. Symbol-  Parameter symbols and model constants             *
C       2. DiffEq-  System differential equations                     *
C       3. Output-  System output equations                           *
C       4. Varmod-  Error variance model equations                    *
C       5. Covmod-  Covariate model equations (ITS,MLEM)              *
C       6. Popinit- Population parameter initial values (ITS,MLEM)    *
C       7. Prior -  Parameter mean and covariance values (ID,NPD,STS) *
C       8. Sparam-  Secondary parameters                              *
C       9. Amat  -  System state matrix                               *
C                                                                     *
C                                                                     * 
C   Additional Subroutine:                                            *                    
C                                                                     *
C     subroutine calc_c(c,t,con) Calculates the                       *
C                                pharmacokinetic c(t)                 *
C                                                                     *
C                                                                     *
C**********************************************************************

C######################################################################C

        Subroutine SYMBOL
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

CC
C----------------------------------------------------------------------C
C                   Enter as Indicated                                 C
C----------------------------------------------------------------------C

      NDEqs   =  16   ! Enter # of Diff. Eqs.
      NSParam =  9    ! Enter # of System Parameters.
      NVparam =  2    ! Enter # of Variance Model Parameters.
      NSecPar =  0    ! Enter # of Secondary Parameters.
      NSecOut =  0    ! Enter # of Secondary Outputs (not used).
      Ieqsol  =  1    ! Indicates a built-in compartment model.
      Descr = 'Arthritis_Model_Exp_B'

CC
C----------------------------------------------------------------------C
C     Enter Symbol for Each System Parameter (eg. Psym(1)='Kel')       C
C----c-----------------------------------------------------------------C

        PSym(1) = 'k1'
        PSym(2) = 'k2'
        PSym(3) = 'k4'
        PSym(4) = 'k5'
        PSym(5) = 'sig1'
        PSym(6) = 'sig2'
	PSym(7) = 'sig3'
	PSym(8) = 'tau'
	PSym(9) = 'I0'


CC
C----------------------------------------------------------------------C
C    Enter Symbol for Each Variance Parameter {eg: PVsym(1)='Sigma'}   C
C----c-----------------------------------------------------------------C

       PVsym(1) = 'SDinter'
       PVsym(2) = 'SDslope'

CC
C----------------------------------------------------------------------C
C    Enter Symbol for Each Secondary Parameter {eg: PSsym(1)='CLt'}    C
C----c-----------------------------------------------------------------C



C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End


c----------------------------------------------------------------------c

C######################################################################C
C
C                Additonal Subroutines
C
C
C Subroutine to calculate c(t)
C Input:  t (days), con (Dosing schedule: 
C                        ndose, amount of first dose,
C                               time point of first dose,...)
C Output: c(t) 
C
C Code by Jeff D. Fischer Pharsight from
C http://www.boomer.org/pk/PK02/PK2002218.html
C 
C The code uses the superposition principle


	Subroutine calc_c(c,t,con)

	Implicit none

	Real*8 t,c
	Real*8 td, t_PK, coef1, coef2
	Real*8 Aiv, Biv, alpha, beta, dose
	Real*8 con(7)
	Real*8 ndose

	Integer i,j


C--	PK parameters in days
	
	Aiv = 20.27D0
	Biv = 17.54D0
	alpha = 0.2256D0 * 24D0
	beta = 0.6453D-2 * 24D0


	if (t .GE. 0) then

	   ndose = con(1)
	   j = 1
	   do i=1,ndose
	      j = j + 2
              if (t .le. con(j)) then 
                 go to 100
              endif
           end do
100	   ndose = i-1
	   c  = 0
           j = 1
           do i=1,ndose
              j = j + 2
              td = t - con(j)
	      dose = con(j-1)
	      coef1 = Aiv*exp(-alpha*td)
	      coef2 = Biv*exp(-beta*td)
              c  = c  + dose * coef1 + dose * coef2
           end do

	else

	   c = 0

	end if

	return
	end



C######################################################################C

        Subroutine DIFFEQ(T,X,XP)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Real*8 T,X(MaxNDE),XP(MaxNDE)

	Real*8 k1, k2, k3, k4, k5, k6
	Real*8 sig1, sig2, sig3, tau
	Real*8 a,bb
	Real*8 eff_v_01, eff_v_1, eff_v_10, eff_h_01, eff_h_1, eff_h_10
	Real*8 c1_01, c1_1, c1_10, c2_01, c2_1, c2_10
	Real*8 con_01(1:7), con_1(1:7), con_10(1:7)

	Integer i,j

	
C-- Dosing schedule 0.1 mg/kg

	con_01(1) = 3D0
	con_01(2) = 0.1D0
	con_01(3) = 1D0
	con_01(4) = 0.1D0
	con_01(5) = 8D0
	con_01(6) = 0.1D0
	con_01(7) = 15D0

C-- Dosing schedule 1 mg/kg

	con_1(1) = 3D0
	con_1(2) = 1D0
	con_1(3) = 1D0
	con_1(4) = 1D0
	con_1(5) = 8D0
	con_1(6) = 1D0
	con_1(7) = 15D0

C-- Dosing schedule 10 mg/kg

	con_10(1) = 3D0
	con_10(2) = 10D0
	con_10(3) = 1D0
	con_10(4) = 10D0
	con_10(5) = 8D0
	con_10(6) = 10D0
	con_10(7) = 15D0



	a = 1D0
	bb = 0.5D0

	k1 = P(1)
	k2 = P(2)
	k3 = 5D0
	k4 = P(3)
	k5 = P(4)
	sig1 = P(5)
	sig2 = P(6)
	sig3 = P(7)
	tau  = P(8)

	if (t .LE. tau) then


C --- Calculate c(t)

	   call calc_c(c1_01,t,con_01)
	   call calc_c(c1_1,t,con_1)
	   call calc_c(c1_10,t,con_10)


C --- PD Control

	   XP(1)  = k3 - (k1/k2)*(1-exp(-k2*t))*(X(1)+a)
  	   XP(2)  = k4*(X(1)+a) - k4*a*exp(bb*(t-tau))
	   XP(3)  = k4*a*exp(bb*(t-tau)) - k5*X(3)
	   XP(4)  = 0


C --- PKPD 0.1 mg/kg

	   eff_v_01 = (sig1*exp(-sig2*c1_01)+sig3)*c1_01

	   XP(5) = k3 - eff_v_01*(X(5)+a) - (k1/k2)*(1-exp(-k2*t))*(X(5)+a)
	   XP(6) = k4*(X(5)+a) - k4*a*exp(bb*(t-tau))
	   XP(7) = k4*a*exp(bb*(t-tau)) - k5*X(7)
	   XP(8) = 0
	  

C --- PKPD 1 mg/kg

	   eff_v_1 = (sig1*exp(-sig2*c1_1)+sig3)*c1_1

	   XP(9)  = k3 - eff_v_1*(X(9)+a) - (k1/k2)*(1-exp(-k2*t))*(X(9)+a)
	   XP(10) = k4*(X(9)+a) - k4*a*exp(bb*(t-tau))
	   XP(11) = k4*a*exp(bb*(t-tau)) - k5*X(11)
	   XP(12) = 0


C --- PKPD 10 mg/kg

	   eff_v_10 = (sig1*exp(-sig2*c1_10)+sig3)*c1_10

	   XP(13) = k3 - eff_v_10*(X(13)+a) - (k1/k2)*(1-exp(-k2*t))*(X(13)+a)
	   XP(14) = k4*(X(13)+a) - k4*a*exp(bb*(t-tau))
	   XP(15) = k4*a*exp(bb*(t-tau)) - k5*X(15)
	   XP(16) = 0

	else


C --- Calculate c(t) and c(t-T)


	   call calc_c(c1_01,t,con_01)
	   call calc_c(c1_1,t,con_1)
	   call calc_c(c1_10,t,con_10)

	   call calc_c(c2_01,t-tau,con_01)
	   call calc_c(c2_1,t-tau,con_1)
	   call calc_c(c2_10,t-tau,con_10)


C --- PD Control

	   XP(1)  = k3 - (k1/k2)*(1-exp(-k2*t))*(X(1)+a)
  	   XP(2)  = k4*(X(1)+a) - k4*(X(4)+a)
	   XP(3)  = k4*(X(4)+a) - k5*X(3)
	   XP(4)  = k3 - (k1/k2)*(1-exp(-k2*(t-tau)))*(X(4)+a)


C --- PKPD 0.1 mg/kg

	   eff_v_01 = (sig1*exp(-sig2*c1_01)+sig3)*c1_01
	   eff_h_01 = (sig1*exp(-sig2*c2_01)+sig3)*c2_01

	   XP(5)  = k3 - eff_v_01*(X(5)+a) - (k1/k2)*(1-exp(-k2*t))*(X(5)+a)
  	   XP(6)  = k4*(X(5)+a) - k4*(X(8)+a)
	   XP(7)  = k4*(X(8)+a) - k5*X(7)
	   XP(8)=k3-eff_h_01*(X(8)+a)-(k1/k2)*(1-exp(-k2*(t-tau)))*(X(8)+a)


C --- PKPD 1 mg/kg

	   eff_v_1 = (sig1*exp(-sig2*c1_1)+sig3)*c1_1
	   eff_h_1 = (sig1*exp(-sig2*c2_1)+sig3)*c2_1

	   XP(9)   = k3 - eff_v_1*(X(9)+a) - (k1/k2)*(1-exp(-k2*t))*(X(9)+a)
  	   XP(10)  = k4*(X(9)+a) - k4*(X(12)+a)
	   XP(11)  = k4*(X(12)+a) - k5*X(11)
	   XP(12)=k3-eff_h_1*(X(12)+a)-(k1/k2)*(1-exp(-k2*(t-tau)))*(X(12)+a)


C --- PKPD 10 mg/kg

	   eff_v_10 = (sig1*exp(-sig2*c1_10)+sig3)*c1_10
	   eff_h_10 = (sig1*exp(-sig2*c2_10)+sig3)*c2_10

	   XP(13)  = k3 - eff_v_10*(X(13)+a) - (k1/k2)*(1-exp(-k2*t))*(X(13)+a)
  	   XP(14)  = k4*(X(13)+a) - k4*(X(16)+a)
	   XP(15)  = k4*(X(16)+a) - k5*X(15)
	   XP(16)=k3-eff_h_10*(X(16)+a)-(k1/k2)*(1-exp(-k2*(t-tau)))*(X(16)+a)


	end if


        Return
        End

C######################################################################C

        Subroutine OUTPUT(Y,T,X)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Real*8 Y(MaxNOE),T,X(MaxNDE)

	
	Y(1) = (X(2)+P(9)) + X(3)
	Y(2) = (X(6)+P(9)) + X(7)
	Y(3) = (X(10)+P(9)) + X(11)
	Y(4) = (X(14)+P(9)) + X(15)
	Y(5) = X(3)
	Y(6) = X(7)
	Y(7) = X(11)
	Y(8) = X(15)

        Return
        End

C######################################################################C

        Subroutine VARMOD(V,T,X,Y)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Real*8 V(MaxNOE),T,X(MaxNDE),Y(MaxNOE)

CC
C----------------------------------------------------------------------C
C       Enter Variance Model Equations Below                           C
C         {e.g. V(1) = PV(1)**2 * Y(1)**PV(2) }                        C
C----c-----------------------------------------------------------------C

        V(1) = (PV(1) + PV(2)*Y(1))**2
        V(2) = (PV(1) + PV(2)*Y(2))**2
        V(3) = (PV(1) + PV(2)*Y(3))**2
        V(4) = (PV(1) + PV(2)*Y(4))**2
        V(5) = (PV(1) + PV(2)*Y(5))**2
        V(6) = (PV(1) + PV(2)*Y(6))**2
        V(7) = (PV(1) + PV(2)*Y(7))**2
        V(8) = (PV(1) + PV(2)*Y(8))**2



C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End

C######################################################################C

        Subroutine COVMOD(Pmean, ICmean, PC)
C  Defines any covariate model equations (MLEM, ITS)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Real*8 PC(MaxNCP)
        Real*8 Pmean(MaxNSP+MaxNDE), ICmean(MaxNDE)

CC
C----------------------------------------------------------------------C
C     Enter # of Covariate Parameters                                  C
C----c-----------------------------------------------------------------C

        NCparam = 0    ! Enter # of Covariate Parameters.

CC
C----------------------------------------------------------------------C
C   Enter Symbol for Covariate Params {eg: PCsym(1)='CLRenal'}         C
C----c-----------------------------------------------------------------C


CC
C----------------------------------------------------------------------C
C   For the Model Params. that Depend on Covariates Enter the Equation C
C         {e.g. Pmean(1) =  PC(1)*R(2) }                               C
C----c-----------------------------------------------------------------C


C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End

C######################################################################C

        Subroutine POPINIT(PmeanI,ICmeanI,PcovI,ICcovI, PCI)
C  Initial parameter values for population program parameters (ITS, MLEM)

        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Integer I,J
        Real*8 PmeanI(MaxNSP+MaxNDE), ICmeanI(MaxNDE)
        Real*8 PcovI(MaxNSP+MaxNDE,MaxNSP+MaxNDE), ICcovI(MaxNDE,MaxNDE)
        Real*8 PCI(MaxNCP)

CC
C----------------------------------------------------------------------C
C  Enter Initial Values for Population Means                           C
C          {  e.g. PmeanI(1) = 10.0    }                               C
C----c-----------------------------------------------------------------C


CC
C----------------------------------------------------------------------C
C   Enter Initial Values for Pop. Covariance Matrix (Lower Triang.)    C
C         {  e.g. PcovI(2,1) = 0.25    }                               C
C----c-----------------------------------------------------------------C


CC
C----------------------------------------------------------------------C
C   Enter Values for Covariate Model Parameters                        C
C         {  e.g. PCI(1) = 2.0    }                                    C
C----c-----------------------------------------------------------------C


C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End

C######################################################################C

        Subroutine PRIOR(Pmean,Pcov,ICmean,ICcov)
C  Parameter mean and covariance values for MAP estimation (ID,NPD,STS)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Integer I,J
        Real*8 Pmean(MaxNSP+MaxNDE), ICmean(MaxNDE)
        Real*8 Pcov(MaxNSP+MaxNDE,MaxNSP+MaxNDE), ICcov(MaxNDE,MaxNDE)

CC
C----------------------------------------------------------------------C
C  Enter Nonzero Elements of Prior Mean Vector                         C
C          {  e.g. Pmean(1) = 10.0    }                                C
C----c-----------------------------------------------------------------C


CC
C----------------------------------------------------------------------C
C   Enter Nonzero Elements of Covariance Matrix (Lower Triang.)       C
C         {  e.g. Pcov(2,1) = 0.25    }                                C
C----c-----------------------------------------------------------------C


C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End

C######################################################################C

        Subroutine SPARAM(PS,P,IC)
        Implicit None

        Include 'globals.inc'

        Real*8 PS(MaxNSECP), P(MaxNSP+MaxNDE), IC(MaxNDE) 


        
C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End
        
C######################################################################C

        Subroutine AMAT(A)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Integer I,J
        Real*8 A(MaxNDE,MaxNDE)

        DO I=1,Ndeqs
           Do J=1,Ndeqs
              A(I,J)=0.0D0
           End Do
        End Do

CC
C----------------------------------------------------------------------C
C    Enter non zero elements of state matrix  {e.g.  A(1,1) = -P(1) }  C
C----c-----------------------------------------------------------------C



C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End

C######################################################################C
